AgentLifecycle

Struct AgentLifecycle 

pub struct AgentLifecycle {
    pub agent_id: AgentId,
    pub agent_name: Option<AgentName>,
    pub version: AgentVersion,
    pub version_number: VersionNumber,
    pub current_state: AgentLifecycleState,
    pub previous_state: Option<AgentLifecycleState>,
    pub transition_timeout: TransitionTimeout,
    pub drain_timeout: DrainTimeout,
    pub pending_requests: PendingRequestCount,
    pub failure_reason: Option<FailureReason>,
}
Agent lifecycle state with metadata

Fields

agent_id: AgentIdagent_name: Option<AgentName>version: AgentVersionversion_number: VersionNumbercurrent_state: AgentLifecycleStateprevious_state: Option<AgentLifecycleState>transition_timeout: TransitionTimeoutdrain_timeout: DrainTimeoutpending_requests: PendingRequestCountfailure_reason: Option<FailureReason>

Implementations

Source

impl AgentLifecycle

pub fn new( agent_id: AgentId, agent_name: Option<AgentName>, version: AgentVersion, version_number: VersionNumber, ) -> Self

Creates a new agent lifecycle in unloaded state

pub fn transition_to( &mut self, new_state: AgentLifecycleState, failure_reason: Option<FailureReason>, ) -> Result<(), StateTransitionError>

Attempts to transition to a new state

Errors

Returns an error if the state transition is invalid.

pub fn start(&mut self) -> Result<(), StateTransitionError>

Starts the agent (Ready -> Running)

Errors

Returns an error if the agent cannot transition to Running state.

pub fn start_draining(&mut self) -> Result<(), StateTransitionError>

Begins draining the agent (Running -> Draining)

Errors

Returns an error if the agent cannot transition to Draining state.

pub fn stop(&mut self) -> Result<(), StateTransitionError>

Stops the agent (Running/Draining/Ready -> Stopped)

Errors

Returns an error if the agent cannot transition to Stopped state.

pub fn fail( &mut self, reason: FailureReason, ) -> Result<(), StateTransitionError>

Marks agent as failed with reason

Errors

Returns an error if the agent cannot transition to Failed state.

pub fn add_pending_request(&mut self) -> Result<(), StateTransitionError>

Increments pending request count

Errors

Returns an error if too many requests are pending.

pub fn complete_request(&mut self)

Decrements pending request count

pub fn is_ready_to_stop(&self) -> bool

Checks if agent is ready to be fully stopped (no pending requests)

pub fn get_timeout_for_state(&self) -> u64

Gets time-based constraints for current state